
(** Internationalisation of your program / library 
  @author Pascal (Pixel) Rigaux
  @version 0.1

  @see <ocaml-simple_gettext-0.1.tar.gz> source

  @see <libsimple-gettext-ocaml_0.1_i386.deb> debian binary (only the shared library)
  @see <libsimple-gettext-ocaml-dev_0.1_i386.deb> debian binary (everything else)
  @see <ocaml-simple_gettext-0.1-1mdk.i586.rpm> mandrake rpm

*)
(**
  {0 Example}
  Typical use: {[
     open Simple_gettext
     ...
     Simple_gettext.textdomain "mathplot";
     ...     
     print_endline (i18n "Hello %s!" name);
  ]}

  Then use [xgettext-ocaml -o foo.pot *.ml]

  More information: {{:http://www.gnu.org/manual/gettext-0.11.2/html_chapter/gettext_1.html#SEC6}overview of gettext}


  {0 Simple_gettext vs OCamlGettext}

   Why did you develop yet another gettext binding?
   Why not use the existing gettext binding (OCamlGettext)?
   
   OCamlGettext is:
  - hard to build (it needs many tools)
  - doesn't handle %s in translated strings (very useful in practice)
  - doesn't have a xgettext (minor pb)

  {0 Functions}
*)

external bindtextdomain: string -> string -> unit = "ocaml_simple_gettext_bindtextdomain";;
(** [bindtextdomain domainname dirname] tells to use directory [dirname] to look for translations for [domainname] *)

external textdomain: string -> unit = "ocaml_simple_gettext_textdomain";;
(** [textdomain domainname] sets current domain used by {!Simple_gettext.gettext} *)

val i18n : ('a, unit, string) format -> 'a
(** [i18n msgid args] returns the string [msgid] translated using current domain (set using {!Simple_gettext.textdomain}) *)

val i18n_ : string -> string
(** [i18n_ msgid] returns the string verbatim. Useful for messages translated later (using {!Simple_gettext.gettext} or {!Simple_gettext.dgettext}) in the program *)

external gettext: string -> string = "ocaml_simple_gettext_gettext";;
(** [gettext msgid] returns the string [msgid] translated using the current domain (set using {!Simple_gettext.textdomain}) *)

external dgettext: string -> string -> string = "ocaml_simple_gettext_dcgettext";;
(** [dgettext domainname msgid] returns the string [msgid] translated using [domainname] *)

(**/**)

external gettext_sprintf: ('a, unit, string) format -> ('a, unit, string) format = "ocaml_simple_gettext_gettext";;
external dgettext_sprintf: string -> ('a, unit, string) format -> ('a, unit, string) format = "ocaml_simple_gettext_dcgettext";;

